Added more wrapper, commented out another noisy debug line
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index 4a2129716d065158336bda6c623067d5abfadca2..c91ff65364b07531d0a7a6016c05e988df7e90d3 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -1,24 +1,23 @@
 <?php
 /************************************************************************
- * MXChange v0.2.1                                    Start: 10/13/2003 *
- * ===============                              Last change: 09/04/2004 *
+ * Mailer v0.2.1-FINAL                                Start: 10/13/2003 *
+ * ===================                          Last change: 09/04/2004 *
  *                                                                      *
  * -------------------------------------------------------------------- *
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
* Short description : Redirection for the referal link                 *
  * -------------------------------------------------------------------- *
* Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *
  * $Date::                                                            $ *
  * $Tag:: 0.2.1-FINAL                                                 $ *
  * $Author::                                                          $ *
- * Needs to be in all Files and every File needs "svn propset           *
- * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
  * -------------------------------------------------------------------- *
- * Copyright (c) 2003 - 2008 by Roland Haeder                           *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2003 - 2009 by Roland Haeder                           *
+ * Copyright (c) 2009 - 2012 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
 // Load security stuff here
 require('inc/libs/security_functions.php');
 
+// Init start time
+$GLOBALS['__start_time'] = microtime(true);
+
 // Set module
-$GLOBALS['module'] = 'ref';
-$GLOBALS['output_mode'] = -1;
+$GLOBALS['__module']      = 'ref';
+$GLOBALS['__output_mode'] = -1;
 
 // Load the required file(s)
 require('inc/config-global.php');
 
-// Redirect only to registration page when this script is installed
-if (!isInstalled()) {
-       // You have to install first!
-       redirectToUrl('install.php');
-} // END - if
-
-// Base URL for redirection
-switch (getConfig('refid_target')) {
-       case 'register':
-               $URL = 'modules.php?module=index&amp;what=register&amp;refid=';
-               break;
-
-       case 'index':
-               $URL = 'index.php?refid=';
-               break;
-}
-
-// Get referal ID from ref or refid variable
-if (REQUEST_ISSET_GET(('ref')))        $ref = REQUEST_GET('ref');
-elseif (REQUEST_ISSET_GET(('refid'))) $ref = REQUEST_GET('refid');
+// Set content type for e.g. search engines
+setContentType('text/html');
 
-if (!empty($ref)) {
-       // Test if nickname or numeric id
-       if ($ref != ''.($ref + 0).'') {
-               if (EXT_IS_ACTIVE('nickname')) {
-                       // Nickname in URL, so load the ID
-                       $result = SQL_QUERY_ESC("SELECT userid FROM `{!_MYSQL_PREFIX!}_user_data` WHERE nickname='%s' LIMIT 1",
-                       array($ref), __FILE__, __LINE__);
+// No refid by default
+$url = 'modules.php?module=index';
 
-                       // Load userid
-                       list($ref) = SQL_FETCHROW($result);
+// Check for determined referral id
+if ((isExtensionActive('user')) && (isReferralIdValid()) && (isValidUserId(determineReferralId()))) {
+       // Update ref counter
+       SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
+               array(convertZeroToNull(determineReferralId())), __FILE__, __LINE__);
 
-                       // Free result
-                       SQL_FREERESULT($result);
-               } else {
-                       // Invalid request!
-                       $ref = 0;
-               }
-       } // END - if
+       // Base URL for redirection
+       switch (getConfig('refid_target')) {
+               case 'register':
+                       $url = 'modules.php?module=index&amp;what=register';
+                       break;
 
-       // Also edit this 0 !
-       if (empty($ref)) $ref = 0;
-
-       // Update session
-       setSession('refid', $ref);
-
-       // We have an refid here. So we simply add it
-       $URL .= bigintval($ref);
-
-       // Is the refid valid?
-       if ($ref > 0) {
-               // Update ref counter
-               SQL_QUERY_ESC("UPDATE `{!_MYSQL_PREFIX!}_user_data` SET ref_clicks=ref_clicks+1 WHERE userid=%s LIMIT 1",
-               array(bigintval($ref)), __FILE__, __LINE__);
-       } // END - if
-} else {
-       // No refid and we add our refid (don't forget to set $def_refid!)
-       $URL = 'index.php';
-}
+               case 'index':
+                       $url = 'modules.php?module=index';
+                       break;
+       } // END - switch
+} // END - if
 
 // Load the URL
-redirectToUrl($URL);
+redirectToUrl($url);
 
 // [EOF]
 ?>
@@ -1,24 +1,23 @@
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
- * Short description : Redirection for the referal link                 *
+ * Short description : Redirection for the referral link                *
  * -------------------------------------------------------------------- *
@@ -1,24 +1,23 @@
  * -------------------------------------------------------------------- *
- * Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
+ * Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *